//Michael Klements
//The DIY Life
//8 February 2020
/*
 * Brett Oliver 08 April 2021
 * v05 created safe boot sequence for digits to avoid clashes on power up
 * v07 slowed down segments
 * v09 all segments calibrated
 * v14 changed startup timings
 * v15 moved safe location and all on display to functions ready for motion detection
 * v16 added 30second RTC sync from master clock added motion detection PIR
 * v18 added code to move segs 2 and 6 out the way after PIR On
 * v19 add time setting
 * v21 set time from pot on restart
 * v22 add segment flag to show which segment is being set at setting time
 * v23 fix clashes after PIR activation and changed movesafe() delay to speed up
 * v24 fix to stop multiple 30 sec syncs and stop digit clashes on restart from PIR
 * v25 add update digits on time setting
 * v26 adjustments to time setting display
 * v27 arm tuneup
 * v28 add extra digit setting on time set. No change for selected digit
 * v29 removed above
 * v30 adjust PIR to just change time when re-activated does not move to "safe" position when PIR is OFF
 * v31 slow display start allOn() to use less power
 * v34 as v 31 do not use 32 or 33
 */

// adjust min unit servo
//#include <virtuabotixRTC.h>               //Include library for clock module
#include <Wire.h>
#define DS3231_I2C_ADDRESS 104
byte tMSB, tLSB;
float temp3231;
byte hh, mm, ss;
byte yy, ll, dd, zz;
#include <Adafruit_PWMServoDriver.h>      //Include library for servo driver

Adafruit_PWMServoDriver pwmH = Adafruit_PWMServoDriver(0x40);    //Create an object of Hour driver
Adafruit_PWMServoDriver pwmM = Adafruit_PWMServoDriver(0x41);    //Create an object of Minute driver (A0 Address Jumper)

int servoFrequency = 50;      //Set servo operating frequency









//                                            HOURS
//Hours               |       Unit Digit          |      Tens Digit          |
 // Segment Number      1   2   3   4   5   6   7   1   2   3   4   5   6   7
 int segmentHOn[14] = {435,415,240,250,365,270,390,440,400,245,255,400,260,415};   //On positions for each Hour servo
int segmentHOff[14] = {230,215,420,440,165,470,185,230,200,435,460,205,450,200};    //Off positions for each Hour servo


 
 
 
 
 
 



 
 
 
 
 
 //                                            MINUTES
 //Minutes             |       Unit Digit         |      Tens Digit          |
 // Segment Number      1   2   3   4   5   6   7   1   2   3   4   5   6   7
 int segmentMOn[14] = {400,400,260,260,370,255,395,410,400,263,280,395,263,380};   //On positions for each Minute servo
int segmentMOff[14] = {190,190,470,490,150,470,180,180,180,480,500,180,480,150};    //Off positions for each Minute servo
 
 
int digits[10][7] = {{1,1,1,1,1,1,0},{0,1,1,0,0,0,0},{1,1,0,1,1,0,1},{1,1,1,1,0,0,1},{0,1,1,0,0,1,1},  // numbers 0,1,2,3,4
                     {1,0,1,1,0,1,1},{1,0,1,1,1,1,1},{1,1,1,0,0,0,0},{1,1,1,1,1,1,1},{1,1,1,1,0,1,1}}; //numbers  5,6,7,8,9,   //Position values for each digit


int hourTens = 0;                 //Create variables to store each 7 segment display numeral
int hourUnits = 0;
int minuteTens = 0;
int minuteUnits = 0;

int prevHourTens = 8;           //Create variables to store the previous numeral displayed on each
int prevHourUnits = 8;          //This is required to move the segments adjacent to the middle ones out of the way when they move
int prevMinuteTens = 8;
int prevMinuteUnits = 8;

int midOffset = 100;            //Amount by which adjacent segments to the middle move away when required

int sync30 = 2; // 30 seconds master clock sync pulse input to set RTC to 30 seconds

int PIR = 3; // PIR input 0 display shows --:-- & 1 display shows time

int moveSafeOn = 1; // prevents segments repeatedly being set to --:-- when PIR is LOW or on start & makes segment 7 offset work no matter what digit

int settingTime = A7;

int digit = 0; //time setting value from pot

int setTimeOn = 4;

int StepTime = 5;

int printOn = 0;//alows serial print once only on setting time

int hrsTens = 0;

int minsTens = 0;

int sync30off = 0;

void setup() 
{
  Serial.begin(115200);
  pwmH.begin();                             //Start each board
  pwmM.begin();
  pwmH.setOscillatorFrequency(27000000);    //Set the PWM oscillator frequency, used for fine calibration
  pwmM.setOscillatorFrequency(27000000);
  pwmH.setPWMFreq(servoFrequency);          //Set the servo operating frequency
  pwmM.setPWMFreq(servoFrequency);

 pinMode(sync30,INPUT);
 
  pinMode(PIR,INPUT);

  pinMode(settingTime,INPUT);

  pinMode (StepTime,INPUT);

 if (digitalRead(setTimeOn) == HIGH)  // If we set the time digits must be in safe position
 {
  Serial.println("Set Time Switch is On ");
  moveSafe();// in case we set the time
 delay(500);

 // Move 7th segment of hrs units, muns 10s and mins units to off
 // Leave hrs 10s On

  //Hrs 10s
 pwmH.setPWM(13, 0, segmentHOff[13]);  // set hrs 10s 7 segment off
    
delay(100);
 
 
 //Hrs Units
 pwmH.setPWM(6, 0, segmentHOff[6]);  // set min units 7 segment off
    
delay(100);


//Mins 10s
  pwmM.setPWM(13, 0, segmentMOff[13]);  // set min 10s 7 segment off
  delay(100); 


//Mins Units
 pwmM.setPWM(6, 0, segmentMOff[6]);  // set min units 7 segment off
    
delay(100);

 Serial.println("");
   Serial.println("Set Time");

 }
  printOn = 1;
  
   
  
  while (digitalRead(setTimeOn) == HIGH) {

    if(printOn == 1 && digitalRead(StepTime) == HIGH )
{
      
      readSetting();
      
      
      hrsTens = digit;
     
      hrsTens = hrsTens *10;
     
    Serial.print("RTC Time Hrs 10s = ");
    Serial.println(hrsTens);
    //DS3231 seconds, minutes, hours, day, date, month, year
 setDS3231time(00, 00, 00, 6, 10, 4, 21); //Date not set
      
   
   if ( hrsTens > 20 )// too high
   {
    Serial.println("must be less than 3");
    printOn = 1;
   }
   else if( hrsTens <= 20 )// within range

   {
  //show digit set
  hourTens = hrsTens/10;
  hourUnits = 0;
  minuteTens = 0;
  minuteUnits = 0;
   moveSafeHrsTens();//set HrsTens digit to "-" to show the digit we are setting
   moveSafeOn = 1;
    
  updateDisplay();

   
  
  
   printOn = 2; // steps to next digit
    delay (500);
   } 
    
}  
    
    

   //  Serial.println("Set Hrs Units ");
     
     if(printOn == 2 && digitalRead(StepTime) == HIGH)
     {
     
    

     readSetting();
      
      
     hh = digit;
      
    hh = hh + hrsTens;
    
    Serial.print("RTC Time Hrs = ");
    Serial.println(hh);
    //Serial.print(":");
    //Serial.print(mm);
   // Serial.print(":");
   // Serial.println(ss);
      
   if ( hh > 23 )
   {
      Serial.println("if hrs 10s are > 2 must be set to < 4 ");
     printOn = 2;// goes back
   }
      else if( hh <= 23 )// within range
     {

   // show digit set
 
  hourUnits = digit;
  minuteTens = 0;
  minuteUnits = 0;
  moveSafeHrsUnits();//set HrsUnits digit to "-" to show the digit we are setting
 // moveSafe();
   moveSafeOn = 1;
  updateDisplay();
     
     
  
    
     delay(100);
     printOn = 3;
     delay (500);
     
    }
      
   // Serial.println("Set Mins 10s ");

     }
    
    
    
    
    
    if(printOn == 3 && digitalRead(StepTime) == HIGH)
    {
      
     
     readSetting();

     minsTens = digit;
     minsTens = minsTens * 10;
     
       
   
    
    Serial.print("RTC Time Mins 10s = ");
   // Serial.print(hh);
   // Serial.print(":");
    Serial.println(minsTens);
   // Serial.print(":");
   // Serial.println(ss);
    

   if ( minsTens > 50 )// too high
   {
    Serial.println("must be less than 5");
    printOn = 3;//goes back
   }
   
    
    else if( minsTens <= 50 )// within range 
   
{
 // show set digit
 
  minuteTens = minsTens/10;
  minuteUnits = 0;
  moveSafeMinsTens();//set MinsTens digit to "-" to show the digit we are setting
 // moveSafe();
   moveSafeOn = 1;
  updateDisplay();
  delay(100);
   
  
   printOn = 4; // steps to next digit
    
    delay (500);
}
   
    }

    // Serial.println("Set Mins Units ");
      

    if(printOn == 4 && digitalRead(StepTime) == HIGH)
    {
     
    
delay(100);
    
     readSetting();
    
     mm = digit;
     mm = mm + minsTens; 
   
     
    Serial.print("RTC Time Mins = ");
    //Serial.print(hh);
   // Serial.print(":");
    Serial.println(mm);
    //Serial.print(":");
   // Serial.println(ss);

 Serial.print("Time will be set to ");
  Serial.print(hh);
   Serial.print(":");
    Serial.println(mm);
    
    //Set Mins Units 7th seg to off to show we have set this digit
 //   pwmM.setPWM(6, 0, segmentMOff[6]);  // set min units 7 segment on
 // show set digit
 //  hourTens = hrsTens/10;
 // hourUnits = digit;
 // minuteTens = minsTens/10;
  minuteUnits = digit;
  moveSafeMinsUnits();//set Mins Units digit to "-" to show the digit we are setting
 // moveSafe();
   moveSafeOn = 1;
  updateDisplay();
    
delay(100);
    printOn = 1;

    //DS3231 seconds, minutes, hours, day, date, month, year
 setDS3231time(00, mm, hh, 6, 10, 4, 21); //Date not set
    
    delay (500);
    
    }
  
  //  Serial.println("To set time again press Time Set ");
   
    
    
   

  }
 //DS3231 seconds, minutes, hours, day, date, month, year
 // setDS3231time(00, 27, 7, 6, 10, 4, 21); //Only required once to reset the clock time
  



moveSafe();// move servos to safe position --:--  segments can be moved from any position to safe position without clashing

allOn(); // servo test  move servos to all on position 88:88


 
  delay(2000);

  
 

}

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

void loop()
{
  
 readDS3231time(&ss, &mm, &hh, &zz, &dd, &ll,&yy);//gets the time from the RTC
  if (digitalRead(PIR) == HIGH)// PIR activated show time
{ 
 
  
  
  int temp = hh;             //Get the hours and save to variable temp
  
  hourTens = temp / 10;               //Split hours into two digits, tens and units
  hourUnits = temp % 10;
  temp = mm;               //Get the minutes and save to variable temp
  
  minuteTens = temp / 10;             //Split minutes into two digits, tens and units
  minuteUnits = temp % 10;

  if(minuteUnits != prevMinuteUnits && moveSafeOn == 0)  //If minute units has changed, update display- moveSafeOn is zero on 2nd update of the display
  // This is because after power up or a PIR sestart we won't know what the previous time was.
  {
    updateDisplay();
 Serial.println("Update display Movesafe =0");
  prevHourTens = hourTens;            //Update previous displayed numerals
  prevHourUnits = hourUnits;
  prevMinuteTens = minuteTens;
  prevMinuteUnits = minuteUnits;
  }

  // Updates display once to change display from --:-- to current time as soon as PIR triggerred again or on first power up
 if (moveSafeOn == 1)//only one if PIR was previously off
 {
   Serial.println("movesafeOn = 1 ");
 //  allOn(); // move servos to all on position 88:88
   
   updateDisplay();
   Serial.println("Update display Movesafe =1"); 

   prevHourTens = hourTens;            //Update previous displayed numerals
  prevHourUnits = hourUnits;
  prevMinuteTens = minuteTens;
  prevMinuteUnits = minuteUnits;
    //################################################
     moveSafeOn = 0; 
Serial.print("moveSafeOn = ");
Serial.println(moveSafeOn); 
//#####################################################
 }
 
  
  
}
 
 else if(digitalRead(PIR) == LOW && moveSafeOn == 0 )// PIR de-activated // move servos to safe position --:--
 {
 
// moveSafe();// move servos to safe position --:--  segments can be moved from any position to safe position without clashing

  moveSafeOn = 1; // prevents segments repeatedly being set to --:-- when PIR is LOW
 }



 

if (digitalRead(sync30) == HIGH && ss >= 1 && ss <= 59 && sync30off == 0)// sync on 30seconds on 30 sec sync if seconds >= 10 and <= 55
{ 
   
  
    
   setDS3231time(30, mm, hh, zz, dd, ll, yy); //Set seconds to 30 on RTC
   
   Serial.println("Sync Pulse");
  Serial.print("RTC Time ");
    Serial.print(hh);
    Serial.print(":");
    Serial.print(mm);
    Serial.print(":");
    Serial.println(ss);
  sync30off = 1;
}



 if (ss > 31 && sync30off == 1) //enable sync after 32 seconds
{
sync30off = 0;
}


 // delay(500);// Brett removed so RTC can be sync'd
}




//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~




void updateDisplay ()                               //Function to update the displayed time
{
  
    
  updateMid();                                      //Move the segments out of the way of the middle segment and then move the middle segments
  for (int i=0 ; i<=5 ; i++)                        //Move the remaining segments
  {
    if(digits[hourTens][i]==1)                      //Update the hour tens
      pwmH.setPWM(i+7, 0, segmentHOn[i+7]);
    else
      pwmH.setPWM(i+7, 0, segmentHOff[i+7]);
    delay(10);
    if(digits[hourUnits][i]==1)                     //Update the hour units
      pwmH.setPWM(i, 0, segmentHOn[i]);
    else
      pwmH.setPWM(i, 0, segmentHOff[i]);
    delay(10);
    if(digits[minuteTens][i]==1)                    //Update the minute tens
      pwmM.setPWM(i+7, 0, segmentMOn[i+7]);
    else
      pwmM.setPWM(i+7, 0, segmentMOff[i+7]);
    delay(10);
    if(digits[minuteUnits][i]==1)                   //Update the minute units
      pwmM.setPWM(i, 0, segmentMOn[i]);
    else
      pwmM.setPWM(i, 0, segmentMOff[i]);
    delay(10);
  }

}

void updateMid()                                              //Function to move the middle segements and adjacent ones out of the way
{ 
  /*
   repeat for mints tens, hours units and hours tens in turn
   
If minutes units have changed

If last minute was 1 and is On
move segment 2 to -ve offset

If last minute was 6 and is On
move segment 6 to +ve offset



delay

If center segment is On
leave On

else

set to Off

   
   */
  
  
  
  
  if(digits[minuteUnits][6]!=digits[prevMinuteUnits][6])      //Move adjacent segments for Minute units
  {
  
    if(digits[prevMinuteUnits][1]==1 || moveSafeOn == 1)
      pwmM.setPWM(1, 0, segmentMOn[1]-midOffset);
      Serial.println("M Units seg 2 Offset ");
    if(digits[prevMinuteUnits][6]==1 || moveSafeOn == 1)
      pwmM.setPWM(5, 0, segmentMOn[5]+midOffset);
      Serial.println("M Units seg 6 Offset ");
  }
  delay(100);                                                 //Delay allows adjacent segments to move before moving middle
  if(digits[minuteUnits][6]==1)                               //Move Minute units middle segment if required
    pwmM.setPWM(6, 0, segmentMOn[6]);
     //Serial.println("M Units seg 7 On ");
  else
    pwmM.setPWM(6, 0, segmentMOff[6]);
    // Serial.println("M Units seg 7 Off ");

     
  if(digits[minuteTens][6]!=digits[prevMinuteTens][6])        //Move adjacent segments for Minute tens
  {
    if(digits[prevMinuteTens][1]==1 || moveSafeOn == 1)
      pwmM.setPWM(8, 0, segmentMOn[8]-midOffset);
      Serial.println("M Tens seg 2 Offset ");
    if(digits[prevMinuteTens][6]==1 || moveSafeOn == 1)
      pwmM.setPWM(12, 0, segmentMOn[12]+midOffset);
       Serial.println("M Tens seg 6 Offset ");
  }
  delay(100);                                                 //Delay allows adjacent segments to move before moving middle
  if(digits[minuteTens][6]==1)                                //Move Minute tens middle segment if required
    pwmM.setPWM(13, 0, segmentMOn[13]);
  else
    pwmM.setPWM(13, 0, segmentMOff[13]);


    
  if(digits[hourUnits][6]!=digits[prevHourUnits][6])          //Move adjacent segments for Hour units
  {
    if(digits[prevHourUnits][1]==1|| moveSafeOn == 1)
      pwmH.setPWM(1, 0, segmentHOn[1]-midOffset);
       Serial.println("H Tens seg 2 Offset ");
    if(digits[prevHourUnits][6]==1|| moveSafeOn == 1)
      pwmH.setPWM(5, 0, segmentHOn[5]+midOffset);
      Serial.println("H Units seg 6 Offset ");
  }
  delay(100);                                                 //Delay allows adjacent segments to move before moving middle
  if(digits[hourUnits][6]==1)                                 //Move Hour units middle segment if required
    pwmH.setPWM(6, 0, segmentHOn[6]);
  else
    pwmH.setPWM(6, 0, segmentHOff[6]);


    
  if(digits[hourTens][6]!=digits[prevHourTens][6])            //Move adjacent segments for Hour tens
  {
    if(digits[prevHourTens][1]==1 || moveSafeOn == 1)
      pwmH.setPWM(8, 0, segmentHOn[8]-midOffset);
      Serial.println("H Tens seg 2 Offset ");
    if(digits[prevHourTens][6]==1 || moveSafeOn == 1)
      pwmH.setPWM(12, 0, segmentHOn[12]+midOffset);
       Serial.println("H Tens seg 6 Offset ");
  }
  delay(100);                                                 //Delay allows adjacent segments to move before moving middle
  if(digits[hourTens][6]==1)                                  //Move Hour tens middle segment if required
    pwmH.setPWM(13, 0, segmentHOn[13]);
  else
    pwmH.setPWM(13, 0, segmentHOff[13]);

 
delay(100);

}


//################################################

// http://forum.arduino.cc/index.php?topic=398891.0
void setDS3231time(byte second, byte minute, byte hour, byte dayOfWeek, byte
                   dayOfMonth, byte month, byte year)
{
    // sets time and date data to DS3231
    Wire.beginTransmission(DS3231_I2C_ADDRESS);
    Wire.write(0); // set next input to start at the seconds register
    Wire.write(decToBcd(second)); // set seconds
    Wire.write(decToBcd(minute)); // set minutes
    Wire.write(decToBcd(hour)); // set hours
    Wire.write(decToBcd(dayOfWeek)); // set day of week (1=Sunday, 7=Saturday)
    Wire.write(decToBcd(dayOfMonth)); // set date (1 to 31)
    Wire.write(decToBcd(month)); // set month
    Wire.write(decToBcd(year)); // set year (0 to 99)
    Wire.endTransmission();
}

// Convert binary coded decimal to normal decimal numbers
byte bcdToDec(byte val)
{
    return ( (val / 16 * 10) + (val % 16) );
}

// Convert normal decimal numbers to binary coded decimal
byte decToBcd(byte val)
{
    return ( (val / 10 * 16) + (val % 10) );
}


void readDS3231time(byte *second,
                    byte *minute,
                    byte *hour,
                    byte *dayOfWeek,
                    byte *dayOfMonth,
                    byte *month,
                    byte *year)
{
    Wire.beginTransmission(DS3231_I2C_ADDRESS);
    Wire.write(0); // set DS3231 register pointer to 00h
    Wire.endTransmission();
    Wire.requestFrom(DS3231_I2C_ADDRESS, 7);
    // request seven bytes of data from DS3231 starting from register 00h
    *second = bcdToDec(Wire.read() & 0x7f);
    *minute = bcdToDec(Wire.read());
    *hour = bcdToDec(Wire.read() & 0x3f);
    *dayOfWeek = bcdToDec(Wire.read());
    *dayOfMonth = bcdToDec(Wire.read());
    *month = bcdToDec(Wire.read());
    *year = bcdToDec(Wire.read());
}


//################################################

// Set all servos to "safe position" display --:--
void moveSafe()

{
  
    Serial.println("Moving Segments to safe position --:-- ");
 // Move Minute units servos to "Safe" position before start
for(int i=0 ; i<=5 ; i++)    // i = segments to test Set all of the servos to on or up ( displayed)
  {
    // Serial.print(i);
   // Serial.println(" Min Off");
     pwmM.setPWM(i, 0, segmentMOff[i]);// set segments 1 to 6 off
    delay(30);

   
  }
  // once segments 1 to 6 are out of the way move segment 7 on
  delay(30);
  pwmM.setPWM(6, 0, segmentMOn[6]);  // set min units 7 segment on
    
delay(300);
  

// Move Minute 10s servos to "Safe" position before start
for(int i=7 ; i<=12 ; i++)    // i = segments to test Set all of the servos to on or up ( displayed)
  {
  //   Serial.print(i);
  //  Serial.println(" Min Off");
     pwmM.setPWM(i, 0, segmentMOff[i]);// set segments 1 to 6 off
    delay(30);

   
  }
  // once segments 1 to 6 are out of the way move segment 7 on
  delay(30);
  pwmM.setPWM(13, 0, segmentMOn[13]);  // set min 10s 7 segment on
  delay(300);
  
// End of Safe boot sequence

 
  
 



 // Move Hours units servos to "Safe" position before start
for(int i=0 ; i<=5 ; i++)    // i = segments to test Set all of the servos to on or up ( displayed)
  {
   //  Serial.print(i);
   // Serial.println(" Hr Off");
     pwmH.setPWM(i, 0, segmentHOff[i]);// set segments 1 to 6 off
    delay(30);

   
  }
  // once segments 1 to 6 are out of the way move segment 7 on
  delay(30);
  pwmH.setPWM(6, 0, segmentHOn[6]);  // set min units 7 segment on
    
delay(300);
  

// Move Hours 10s servos to "Safe" position before start
for(int i=7 ; i<=12 ; i++)    // i = segments to test Set all of the servos to on or up ( displayed)
  {
   //  Serial.print(i);
   // Serial.println(" Hr Off");
     pwmH.setPWM(i, 0, segmentHOff[i]);// set segments 1 to 6 off
    delay(30);

   
  }
  // once segments 1 to 6 are out of the way move segment 7 on
  delay(30);
  pwmH.setPWM(13, 0, segmentHOn[13]);  // set min 10s 7 segment on
  delay(300);
  
// End of Safe boot sequence 
}
//###############################################################


//###############################################################
void allOn() // move servos to all on position 88:88 
{
  
  Serial.println("Set all of the servos to on or up (88:88 displayed)");

  for(int i=0 ; i<=5 ; i++)    //Set all of the servos to on or up (88:88 displayed)not 7th segment of each display as already up from safe position
  {
    pwmM.setPWM(i, 0, segmentMOn[i]);
    
    delay(20);
    
  }

   delay(300);

   for(int i=7 ; i<=12 ; i++)    //Set all of the servos to on or up (88:88 displayed)not 7th segment of each display as already up from safe position
  {
    pwmM.setPWM(i, 0, segmentMOn[i]);
    
    delay(10);
    
  }

 delay(300);

for(int i=0 ; i<=5 ; i++)    //Set all of the servos to on or up (88:88 displayed)not 7th segment of each display as already up from safe position
  {
    pwmH.setPWM(i, 0, segmentHOn[i]);
    
    delay(20);
    
  }


 delay(300);
  
  
  for(int i=7 ; i<=12 ; i++)    //Set all of the servos to on or up (88:88 displayed)
  {
    pwmH.setPWM(i, 0, segmentHOn[i]);
    
    delay(20);
    
  }
}
//###############################################################



//###############################################################
// read analog value from pot and give it a value of 1 to 10 for time setting
void readSetting()
{
Serial.println(analogRead(settingTime));//analog setting value 
  
if (analogRead(settingTime) >= 0 && analogRead(settingTime) <= 93)
{
digit = 0;
}

else if (analogRead(settingTime) >= 94 && analogRead(settingTime) <= 187)
{
digit = 1;
}


else if (analogRead(settingTime) >= 188 && analogRead(settingTime) <= 281)
{
digit = 2;
}


else if (analogRead(settingTime) >= 282 && analogRead(settingTime) <= 375)
{
digit = 3;
}


else if (analogRead(settingTime) >= 376 && analogRead(settingTime) <= 469)
{
digit = 4;
}


else if (analogRead(settingTime) >= 470 && analogRead(settingTime) <= 563)
{
digit = 5;
}

else if (analogRead(settingTime) >= 564 && analogRead(settingTime) <= 657)
{
digit = 6;
}


else if (analogRead(settingTime) >= 658 && analogRead(settingTime) <= 751)
{
digit = 7;
}


else if (analogRead(settingTime) >= 752 && analogRead(settingTime) <= 845)
{
digit = 8;
}


else if (analogRead(settingTime) >= 846 && analogRead(settingTime) < 939)
{
digit = 9;
}

else if (analogRead(settingTime) >= 940 && analogRead(settingTime) < 1033)
{
digit = 9;
}

}
 //########################################################################### 


 //####################################
// Set all mins units servos to "safe position" when setting time on this digit  display -
void moveSafeMinsUnits()

{
  
    Serial.println("Moving Segments to safe position --:-- ");
 // Move Minute units servos to "Safe" position before start
for(int i=0 ; i<=5 ; i++)    // i = segments to test Set all of the servos to on or up ( displayed)
  {
    // Serial.print(i);
   // Serial.println(" Min Off");
     pwmM.setPWM(i, 0, segmentMOff[i]);// set segments 1 to 6 off
    delay(30);

   
  }
  // once segments 1 to 6 are out of the way move segment 7 on
  delay(30);
  pwmM.setPWM(6, 0, segmentMOn[6]);  // set min units 7 segment on
    
delay(300);

}

//####################################

//####################################

// Set all mins10s servos to "safe position" when setting time on this digit  display -
void moveSafeMinsTens()

{

// Move Minute 10s servos to "Safe" position before start
for(int i=7 ; i<=12 ; i++)    // i = segments to test Set all of the servos to on or up ( displayed)
  {
  //   Serial.print(i);
  //  Serial.println(" Min Off");
     pwmM.setPWM(i, 0, segmentMOff[i]);// set segments 1 to 6 off
    delay(30);

   
  }
  // once segments 1 to 6 are out of the way move segment 7 on
  delay(30);
  pwmM.setPWM(13, 0, segmentMOn[13]);  // set min 10s 7 segment on
  delay(300);
  
  }
 //#################################### 
  
  
 //#################################### 
  // Set all hrsUnits servos to "safe position" when setting time on this digit  display -
void moveSafeHrsUnits()
{

  // Move Hours units servos to "Safe" position before start
for(int i=0 ; i<=5 ; i++)    // i = segments to test Set all of the servos to on or up ( displayed)
  {
   //  Serial.print(i);
   // Serial.println(" Hr Off");
     pwmH.setPWM(i, 0, segmentHOff[i]);// set segments 1 to 6 off
    delay(30);

   
  }
  // once segments 1 to 6 are out of the way move segment 7 on
  delay(30);
  pwmH.setPWM(6, 0, segmentHOn[6]);  // set min units 7 segment on
    
delay(300);
  }
  
  //####################################
  
  
  //####################################
  // Set all hrsTens servos to "safe position" when setting time on this digit  display -
void moveSafeHrsTens()

{

  // Move Hours 10s servos to "Safe" position before start
for(int i=7 ; i<=12 ; i++)    // i = segments to test Set all of the servos to on or up ( displayed)
  {
   //  Serial.print(i);
   // Serial.println(" Hr Off");
     pwmH.setPWM(i, 0, segmentHOff[i]);// set segments 1 to 6 off
    delay(30);

   
  }
  // once segments 1 to 6 are out of the way move segment 7 on
  delay(30);
  pwmH.setPWM(13, 0, segmentHOn[13]);  // set min 10s 7 segment on
  delay(300);
  
  }
  
  //####################################
